# Source code: Phaser cells

This repository contains the source code for the 'spatial phase codes' (`spc`)
project that characterized recordings of neurons termed 'phaser cells' from
the lateral septum and hippocampus. This software produced the results (data,
figures, statistics) for the two manuscripts regarding phaser cells:

First, in 2017, we published a preprint with early iterations of the analysis
and simulations:

> Monaco, J. D., Blair, H. T., & Zhang, K. (2017). Spatial theta cells in
> competitive burst synchronization networks: Reference frames from phase codes.
> BioRxiv, 211458. [doi: 10.1101/211458](https://doi.org/10.1101/211458)

Second, we have published a more comprehensive narrative of the phaser cell
phenomena and simulation studies in PLOS Computational Biology (link not
available at time of code release):

> Monaco, J. D., De Guzman, R. M., Blair, H. T., & Zhang, K. (2019).
> Spatial synchronization codes from coupled rate-phase neurons. PLOS
> Computational Biology. [doi: 10.1371/journal.pcbi.1006741](https://doi.org/10.1371/journal.pcbi.1006741)

Author affiliations:

> JDM, KZ: Biomedical Engineering Department, Johns Hopkins University School of
> Medicine;  
> HTB: Department of Psychology, UCLA;  
> RMD: Department of Psychology, SUNY Albany

## Installation

The code was developed on a macOS installation of the
[Anaconda](https://www.anaconda.com/download/#macos) scientific python
distribution (using python 3.4.5). The development environment is specified
in the `environment.yml` file. Thus, you should be able to recreate the `spc`
python environment on a Mac with the `conda` command:

```bash
$ cd /path/to/spc-code
$ conda create -n spc --file environment.yml
```

The main source code package is the `spc` directory, but there are three support
packages: `roto` (toolbox functions), `pouty` (logging/output), and `tenko`
(analysis context). After activating the conda environment, the `setuptools`
script should install all the packages:

```bash
$ source activate spc
$ python setup.py install
```

Or you can use `pip` to do an in-place 'developer' install of each of the
packages:

```bash
$ pip install --no-deps -e spc
$ pip install --no-deps -e roto
$ pip install --no-deps -e pouty
$ pip install --no-deps -e tenko
```

## Downloading the data

There are two components to the phaser cell project's data: 

1. The processed recording data (including computed spatial maps) that served
as the basis for all data analysis is available at `/HDF/spc-dataset.zip` in
a [data repository](https://osf.io/psbcw). maintained by the [Open Science
Foundation](https://osf.io) (OSF.io).

2. The intermediate data for each particular analysis or simulation presented
in the paper is available at `/Analysis/spc-results.zip` in the [OSF.io
repository](https://osf.io/psbcw).

To install the data for use with the project's source code, unzip both files
inside of a `projects/spc` folder in your home directory, e.g.:

```bash
$ mkdir -p ~/projects/spc
$ mv ~/Downloads/spc*zip ~/projects/spc
$ cd ~/projects/spc
$ unzip spc-dataset.zip && rm spc-dataset.zip
$ unzip spc-results.zip && rm spc-results.zip
```

If you install the data to a different location, then you may need to edit the
data path defined in `spc/__init__.py`.

## Running the code

If you have the intermediate analysis data installed at
`~/projects/spc/results/` (see above), then all of the figures from the paper
can be generated by running the `spc/figures.py` module:

```python
In[0]: from spc.figures import PaperFigures
In[1]: figs = PaperFigures.load('~/projects/spc/results/2017-10-05+paper-figures')
In[2]: figs.run_all_figures()
```

There is a Jupyter notebook in the `nb` directory that walks through most of the
data analysis and statistics used in the paper (not including simulations). The
notebook illustrates how analysis objects should be loaded from the `spc.ana`
subpackage and how their various analysis and plotting functions can be called.

## Files

* `README.md`: this README file
* `LICENSE.txt`: the software license
* `setup.py`: setuptools installation file
* `environment.yml`: conda environment specification file
* `matplotlibrc`: config file for the Matplotlib plotting library

## Directories

The main code library is in the `spc` subdirectory.

* `nb/`: Jupyter notebook of theta cell analysis
* `pouty/`: auxiliary output/logging package
* `roto/`: auxiliary toolbox package
* `scripts/`: scripts that were used to create the HDF file of processed
recordings data
* `spc/`: main package implementing the project
    * `ana/`: analysis and simulation code modules
    * `lib/`: custom project-specific libraries
    * `tools/`: custom project-specific tools
* `tenko/`: auxiliary analysis context package
* `tests/`: testing code produced during development (these are not software
tests)

## Note

This is research code, so there is no guarantee that it is fit for any
particular purpose. It is a software artifact that was used to produce the
results presented in the manuscripts. This code should allow reproduction of
all results, in combination with the datasets described above, but unforeseen
problems with technical compatibility in the future may prevent reproducibility.
If there are obvious problems or crashes that should be resolved, the code may
be forked and patched, or you can email me at `jmonaco [at] jhu [dot] edu`.

