#!/usr/bin/env python

"""
Create sessions table and data tree for recording sessions.
"""

import os
import sys
from operator import itemgetter

from lco import store
from lco.output import log
from lco.lib.data import new_table, new_group, session_path, sessions_desc, Arenas
from lco.lib.datasets import find_dataset_paths


USE_RAWSPIKES = True


def logit(s):
    log('[{id}] Rat {rat}, Day {day}, "{comment}": {group}', **s)

def main():
    """Store recording session information in the /sessions table."""
    sessions = find_dataset_paths(use_rawspikes=USE_RAWSPIKES)
    table = new_table('/', 'sessions', sessions_desc)
    table._v_attrs['rawspikes'] = USE_RAWSPIKES
    record = table.row
    for i, session in enumerate(sorted(sessions, key=itemgetter('rat', 'day'))):
        session['id'] = i
        session['group'] = session_path(session)
        session['arena'] = Arenas.circle  # default
        if session['comment'].lower() == 'bigarena':
            session['arena'] = Arenas.large
        elif session['comment'].find('square') != -1:
            session['arena'] = Arenas.square

        # Write the table record
        for k in sessions_desc.keys():
            record[k] = session[k]
        record.append()

        # Create the data group
        parent, name = os.path.split(session['group'])
        new_group(parent, name,
            title='Rat {rat}, Day {day}, {comment}'.format(**session))

        logit(session)

    store.flush()
    store.close()
    return 0

if __name__ == "__main__":
    sys.exit(main())
