#!/usr/bin/env python
# coding: utf-8

"""
Export the main database tables to Matlab files.
"""

import os
import sys
import scipy.io as sio
from collections import OrderedDict

import tables as tb

from spc import store, PROJECT_ROOT
from pouty import log


exportdir = os.path.join(PROJECT_ROOT, 'exports')
exports = [
        ('/sessions', 'sessions.mat'),
        ('/recordings', 'recordings.mat'),
        ('/tables/properties', 'properties.mat')
]


def main():
    """Export database tables to individual Matlab files."""
    df = store.get()

    if not os.path.isdir(exportdir):
        os.makedirs(exportdir)

    for tblpath, matfn in exports:
        try:
            table = df.get_node(tblpath)
        except tb.NoSuchNodeError:
            log('Missing table: {}', tblpath, error=True)
            continue

        matpath = os.path.join(exportdir, matfn)
        odict = OrderedDict()
        for cname in table.colnames:
            data = table.col(cname)
            if data.dtype == bool:
                data = data.astype('i')
            odict[cname] = data

        sio.savemat(matpath, odict)
        log('Exported {} → {}', tblpath, matpath)

    store.close()


if __name__ == "__main__":
    sys.exit(main())
