#!/usr/bin/env python
# coding: utf-8

"""
Import position time-series data for each recording session into the h5 file.
"""

import os
import sys

import numpy as np
import scipy.io as sio
import tables as tb

from lco import store
from lco.output import log
from lco.lib.data import new_array


def main(overwrite=False):
    """Load normalized tracking data from posxdata.mat files."""
    f = store.get(readonly=False)
    sessions = f.root.sessions

    for session in sessions.iterrows():
        group = os.path.join(session['group'], 'tracking')
        if not overwrite:
            try:
                node = f.get_node(group, 'TS')
            except tb.NoSuchNodeError:
                pass
            else:
                continue

        log('Loading posxdata: Rat {}, Day {}, {}',
            session['rat'], session['day'], session['comment'].title())

        posx_path = os.path.join(session['path'], 'posxdata.mat')
        try:
            posx = sio.loadmat(posx_path)
        except ValueError as e:
            log('Failed to load {}: {}', posx_path, e.message, error=True)
            continue

        data = {k:posx[v].squeeze() for k,v in [
                ('TS', 'Position_TS'), ('X', 'posx0'), ('Y', 'posx90')
            ]}

        log('→ Importing {} position samples...', data['TS'].size)
        for key in data:
            arr = new_array(group, key, data[key], createparents=True)

        if session['id'] % 5 == 0:
            store.flush()

    store.close()
    return 0


if __name__ == "__main__":
    sys.exit(main())
