#!/usr/bin/env python
# coding: utf-8

"""
Pull position data out of trackdata for Theta11/Day 26.
"""

import os
import sys

import numpy as np
import scipy.io as sio
import tables as tb

from lco import store
from lco.output import log
from lco.lib.data import new_array


def normalize(X):
    return 100.0 * (X - X.min()) / (X.max() - X.min())

def main(overwrite=True):
    """Load tracking data from trackdata.mat files."""
    f = store.get(readonly=False)
    sessions = f.root.sessions

    condn = '(rat==11)&(day==26)&(comment!="square")'
    for session in sessions.where(condn):
        group = os.path.join(session['group'], 'tracking')
        if not overwrite:
            try:
                node = f.get_node(group, 'HD')
            except tb.NoSuchNodeError:
                pass
            else:
                continue

        log('Loading trackdata: Rat {}, Day {}, {}',
            session['rat'], session['day'], session['comment'].title())

        track_path = os.path.join(session['path'], 'trackdata.mat')
        try:
            track = sio.loadmat(track_path)
        except ValueError as e:
            log('Failed to load {}: {}', track_path, e.message, error=True)
            continue

        data = {k:normalize(track[v][:,0].squeeze()) for k,v in [
                ('X', 'Position_X'),
                ('Y', 'Position_Y')
            ]}
        data['TS'] = track['Position_X'][:,1].squeeze()

        log('→ Importing {} tracking samples...', data['X'].size)
        for key in data:
            arr = new_array(group, key, data[key], overwrite=True,
                    createparents=True)

    store.close()
    return 0


if __name__ == "__main__":
    sys.exit(main())

