#!/usr/bin/env python
# coding: utf-8

"""
Import head/movement direction and speed data for each recording session.
"""

import os
import sys

import numpy as np
import scipy.io as sio
import tables as tb

from lco import store
from lco.output import log
from lco.lib.data import new_array


#NOTE: Due to issues with the speed and pre-filtered intervals, those are
# no longer imported here. The head direction is the only important motion
# data imported by this script. Angular velocity (AV) is imported, but it is
# only accessed through the MotionData.av_orig attribute.


def main(overwrite=True):
    """Load tracking data from trackdata.mat files."""
    f = store.get(readonly=False)
    sessions = f.root.sessions

    for session in sessions.iterrows():
        group = os.path.join(session['group'], 'tracking')
        if not overwrite:
            try:
                node = f.get_node(group, 'HD')
            except tb.NoSuchNodeError:
                pass
            else:
                continue

        log('Loading trackdata: Rat {}, Day {}, {}',
            session['rat'], session['day'], session['comment'].title())

        track_path = os.path.join(session['path'], 'trackdata.mat')
        try:
            track = sio.loadmat(track_path)
        except ValueError as e:
            log('Failed to load {}: {}', track_path, e.message, error=True)
            continue

        data = {k:track[v][:,0].squeeze() for k,v in [
                ('AV', 'Position_AV'),
                #('MD', 'Position_MD'),
                ('HD', 'Position_HD')  #,
                #('speed', 'Position_Speed')
            ]}
        #data.update({k:track[v].squeeze() for k,v in [
                #('intervals_fast', 'fastints'),
                #('intervals_slow', 'slowints'),
                #('intervals_still', 'stillints')
            #]})

        log('→ Importing {} tracking samples...', data['AV'].size)
        for key in data:
            arr = new_array(group, key, data[key], createparents=True)

        if session['id'] % 5 == 0:
            store.flush()

    store.close()
    return 0


if __name__ == "__main__":
    sys.exit(main())
