#!/usr/bin/env python
# coding: utf-8

"""
Create symbolic links in dataset folders to raw spike train data.
"""

import re
import os
import sys
import glob

from lco import DATA_ROOT
from lco.output import log
from lco.datasets import RAWSPIKES_FILE


RAW_DATA_ROOT = os.path.join(DATA_ROOT, 'ThetaRawtrains')
LABEL_FROM_RAWFILE = '([-\w]*)rawspikes.mat'
RAT_FROM_LABEL = '([a-zA-Z\d]*)_.*'


def main():
    """For each raw spikes file, link it to the corresponding dataset."""
    rawfiles = glob.glob(os.path.join(RAW_DATA_ROOT, "*.mat"))
    log('Found {} raw spikes files.', len(rawfiles))

    nlinks = 0
    labelpat = re.compile(LABEL_FROM_RAWFILE)
    ratpat = re.compile(RAT_FROM_LABEL)

    for rawpath in rawfiles:
        path, fn = os.path.split(rawpath)

        match = re.match(labelpat, fn)
        if match is None:
            log('Could not find label for {}', fn, error=True)
            continue
        label = match.groups()[0][:-1]  # remove trailing underscore

        match = re.match(ratpat, label)
        if match is None:
            log('Could not find rat for {}', label, error=True)
        rat = match.groups()[0]

        datapath = os.path.join(DATA_ROOT, rat, label)
        if not os.path.isdir(datapath):
            log('Could not find dataset: {}', datapath, error=True)

        newpath = os.path.join(datapath, RAWSPIKES_FILE)
        log('Linking {} → {}', rawpath, newpath)
        os.link(rawpath, newpath)

        if os.path.isfile(newpath):
            nlinks += 1
        else:
            log('Error linking to new path!', error=True)

    log('Successfully linked {}/{} files!', nlinks, len(rawfiles))
    return 0


if __name__ == "__main__":
    sys.exit(main())
