## Notes about LCO scripts and what they do

There are a set of scripts for building up the main hierarchical data file (theta.h5). These comb through the raw dataset from the Blair lab and extract both data and metadata to store in tables and arrays in the h5 file.

### Early versions of the LCO phase model

1. [rate-model-trajectory-data.py](file:///Users/joe/source/lco/scripts/rate-model-trajectory-data.py)

    This script encapsulates the phase/rate-model simulations that were used to generate the 2014 SfN poster. The code was extracted from the original IPython notebooks, which are archived elsewhere. This script can be used to replicate or modify the model in those simulations.


### Database construction


These scripts for importing the raw data are roughly in the order that they should be run to build up the database file from scratch.

1. [link-raw-spike-trains.py](file:///Users/joe/source/lco/scripts/link-raw-spike-trains.py)

    Create hard links in dataset folders to raw spike train data. The raw spikes should be stored in the `ThetaRawtrains` subfolder of the root folder. This script creates hard linked files named `rawspikes.mat` in each of the corresponding dataset folders.

1. [create-sessions-tree.py](file:///Users/joe/source/lco/scripts/create-sessions-tree.py)

    This should be the first script to run, it can create the theta.h5 file. It scans the subfolders of the dataset and detects which contain recording sessions based on the subfolder name. It creates the `/sessions` table and records basic metadata of each session: `rat`, `day`, `arena`, `comment`, `path` (filesystem), and `group` (h5 group path). In parallel, this script constructs the hierarchical tree that will store all of the data under the `/data` group.

1. [import-cell-structs.py](file:///Users/joe/source/lco/scripts/import-cell-structs.py)

    This script reads the metadata about individual clusters stored in `cellstructs.mat` files in the original dataset and generates the `/recordings` table in the h5 file. This table contains a `session_id` field referenced to a row of `/sessions` along with information about the cluster: `tt` (tetrode number), `cluster` (cluster number), `ttc` (cluster string name), `cell_id` (cell-tracking id), `site` (recording site), `area` (enumeration of general brain area).

1. [import-spike-trains.py](file:///Users/joe/source/lco/scripts/import-spike-trains.py)

    Based on the data in `/sessions` and `/recordings`, this script iterates across all known clusters and loads the spike train data (for `fast`, `slow`, and `still` velocity intervals) into the `spikes` subgroup of the corresponding session group in the `/data` hierarchy.

1. [import-position-data.py](file:///Users/joe/source/lco/scripts/import-position-data.py)

    For each recording session, the `posxdata.mat` is read and the `(X,Y)` position traces and `TS` timestamp array are stored as array nodes under the `tracking` subgroup of the session group. These arrays are called `X`, `Y`, and `TS` as expected.

1. [import-tracking-data.py](file:///Users/joe/source/lco/scripts/import-tracking-data.py)

    Like `import-position-data.py`, this imports trajectory data, but reads directional and speed data from the `trackdata.mat` file for each session. This script saves the array nodes `HD` (head direction), `MD` (movement direction), `AV` (head-angular velocity), and `speed` (positional speed, units unclear). In addition, the velocity-filtering intervals are stored in `intervals_fast`, `intervals_slow`, and `intervals_still`.

1. [import-theta11-day26-position-data.py](file:///Users/joe/source/lco/scripts/import-theta11-day26-position-data.py)

    This script fixes an issue with the original data where the `circle` and `square2` position data files were overwritten in the `Theta11_Day26` sessions by the `square` data. This is fixed by retrieving the position data from the appropriate `trackdata.mat` files, normalizing the coordinates in the same way as the `posxdata.mat` files, and then overwriting the original (incorrect) position data in the database.

1. [import-phase.data.py](file:///Users/joe/source/lco/scripts/import-phase-data.py)

    Import LFP theta-phase data for each recording session into the h5 file. This script reads the `CSCts` and `Aphase` variables of the `LFPphase.mat` files in each session and saves the data to the `LFP` subgroups in the h5 data tree.

### Database analytics

1. [area-site-network.py](file:///Users/joe/source/lco/scripts/area-site-network.py)

    Each cell is labeled with both a recording site (an abbreviated anatomical name) and a general brain area (coded numerically by the numbers 1-5). This script constructs a weighted graph of area&mdash;site pairs, where the weighting is proportional to the number of instances a given pair appears in the database. The graph is plotted in a concentric shell layout with the areas 1-5 in the inner ring and anatomical recordings sites arranged around the outer ring. The plot is saved to the project root folder, and takes the number of weighted-edge levels as a command-line argument.

2. [export-database-tables-to-matlab.py](file:///Users/joe/source/lco/scripts/export-database-tables-to-matlab.py)

    For collaborating with others who need alternatives to the HDF-5 data files, this script will export the main database tables to individual Matlab `.mat` files with the columns as arrays. Boolean arrays are converted to 0/1 integer values.

### Visualization

1. [viztemplate.py](file:///Users/joe/source/lco/scripts/viztemplate.py)

    Based on the visualization scripts that I used to quickly generate the plots for the Cosyne poster, this template should be the starting point for future quick visualization of lots of plots. Set the `interactive` variable at the top to control whether figure windows are created (`True`) or figure images are saved (`False`). The script sets up global plotting state and corresponding `new_figure()` and `next_axis()` functions. 
