#!/usr/bin/env python

"""
A template script with boilerplate for creating figures and plots.
"""

import os

import numpy as np
import matplotlib.pyplot as plt

from lco import PROJECT_ROOT, log
from lco.tools import maps, paths


############## Set up output directories ###############

outputdir = os.path.join(PROJECT_ROOT, 'output')


############## Plotting state and functions ###############

interactive = False

cur = 0
f = None
axlist = None

def new_figure(rows, cols, figsize):
    global f, axlist, cur
    cur = 0
    f, axlist = plt.subplots(nrows=rows, ncols=cols, figsize=figsize)
    axlist = axlist.flatten()
    [ax.set_axis_off() for ax in axlist]
    return f

def next_axis():
    global cur
    if cur == len(axlist):
        raise ValueError, 'out of axis (cur == %d)' % cur
    ax = axlist[cur]
    cur += 1
    return ax

def save_and_close(stem='misc/panel', dpi=150):
    f.set_tight_layout(True)
    if interactive:
        log('Displayed: {}', stem)
        return
    stem = os.path.join(outputdir, stem)
    head, tail = os.path.split(stem)
    if not os.path.isdir(head):
        os.makedirs(head)
    fn = paths.uniquify(stem, ext='png', fmt='%s-%02d')
    plt.savefig(fn, dpi=dpi)
    log('Saved: {}', fn)
    plt.close()

plt.ioff()


############## Helper functions ###############

def quicktitle(ax, title):
    if title:
        ax.text(50.0, 100.0, title, size='x-small', ha='center', va='bottom')

def plot_spatial_map(M, label='', **kwargs):
    ax = next_axis()
    im = maps.plot_map(M, size=100.0, ax=ax, **kwargs)
    quicktitle(ax, label)


############## Script for the generation of many maps ###############

new_figure(2, 2, (11, 8.5))

for i in xrange(4):
    plot_spatial_map(np.random.randn(100, 100), label='Rando %d' % (i+1))

save_and_close('random/test1')


new_figure(3, 3, (11, 8.5))

for i in xrange(9):
    plot_spatial_map(np.random.randn(100, 100), label='Rando %d' % (i+1))

save_and_close('random/test2')


############## Draw anything left back to the screen ###############

plt.ion()
if interactive:
    plt.draw()
    plt.show()
