"""
Test MD/HD correlation by looking at a heatmap.
"""

import numpy as np

from roto import plots, axis, reports

from .. import store
from ..context import SPCAnalysis, step
from ..lib import session, labels


class MDHDCorrelationReport(SPCAnalysis):

    """
    Check for proper diagonal correlation between movement and head direction.
    """

    @step
    def generate_report(self, session_list='all', **rgbargs):
        """Generate a per-session axes report of MD/HD joint densities."""

        stable = store.get().root.sessions
        if session_list == 'all':
            session_list = stable.col('id')
        else:
            session_list = np.squeeze(np.atleast_1d(session_list))

        rpath = self.path('md-hd-report')
        N = len(session_list)

        with reports.AxesReport(rpath, naxes=N, rows=6, cols=4) as report:
            for s_id in session_list:
                sdata = session.get(s_id)
                mdata = sdata.motion
                fast = sdata.motion_filter()

                md = mdata.md[fast]
                hd = mdata.hd_orig[fast] * (np.pi/180)

                ax = report.next_axes()
                plots.heatmap(md, hd, ax=ax, bins=48, **rgbargs)
                ax.set_axis_off()
                axis.quicktitle(ax, labels.session_id(s_id), size='x-small')

                if report.firstcol:
                    axis.ylabel(ax, 'HD (rad)')
                if report.lastrow:
                    axis.xlabel(ax, 'MD (rad)')

        store.close()
