"""
Debug weird chunking effect in some adaptive phasemaps.
"""

import numpy as np
import matplotlib.pyplot as plt
import matplotlib as mpl

from spc.lib import cell
from spc.tools import maps, kernels, circstats
from spc.tools.adaptive import smooth_mask2d

import spc.tools.kernels
import spc.tools.adaptive
import spc.lib.session
reload(spc.tools.kernels)
reload(spc.tools.adaptive)
reload(spc.lib.session)

def phase_vector(weights, values):
    """Multi-output kernel function to compute mean phase vectors."""
    phi = circstats.mean_vector(values, weights=weights)
    if not np.all(np.isfinite(phi)):
        import pdb; pdb.set_trace()
    return phi

def eval_pixels(mask):
    """Compute the pixel grid of kernel evaluation points."""
    _nx, _ny = 64, 64
    _x = np.linspace(0, 100, _nx)
    _y = np.linspace(0, 100, _ny)
    X, Y = np.meshgrid(_x, _y)
    pixels = np.c_[X.T.flatten(), Y.T.flatten()]
    test = np.logical_not(mask.flatten())
    return pixels[test]

def _reshape_grid(pts, mask):
    m = mask.flatten()
    grid = np.zeros(m.size)
    grid[m] = np.nan
    grid[np.logical_not(m)] = pts
    grid = np.reshape(grid, (64,64))
    return grid

weird_cells = [1158, 1033, 648]
c_id = weird_cells[2]
cbar = False

C = cell.record(c_id)
S = cell.session_for(c_id)

ts, xs, ys = S._spkdata(C, 'fast', None, False)
phase = S.lfp.F('phase', ts)

debug = {}
mask = smooth_mask2d(S.motion.x, S.motion.y)
posdata = np.c_[xs, ys]
k = kernels.AdaptiveGaussianKernel(
        posdata,
        k_neighbors=int(posdata.shape[0] * 0.04),
        values=phase)

testpx = eval_pixels(mask)
L_phase = k(testpx,
        minrad=8.0, maxrad=30.0, mask_value=0.0,
        kernel_func=phase_vector, n_outputs=2, debug=debug)
G_phase = np.empty((2,64,64))
G_phase[0] = _reshape_grid(L_phase[0], mask)
G_phase[1] = _reshape_grid(L_phase[1], mask)
P = G_phase
radmap = _reshape_grid(debug['rad'], mask)
adaptmap = _reshape_grid(debug['adapt'], mask)

plt.ioff()
plt.figure()

g = mpl.gridspec.GridSpec(2,4)
fig = plt.figure(100, (11,8))
fig.clear()

ax = fig.add_subplot(g[0,0])
maps.plot(mask, ax=ax, cmap='gray_r', cbar=cbar)
ax.set_axis_off()

ax = fig.add_subplot(g[0,1])
maps.plot(P[0], ax=ax, cmap='hsv', cmin=-np.pi, cmax=np.pi, circular=True,
        mask_color='0.5', cbar=cbar)
ax.set_axis_off()

ax = fig.add_subplot(g[0,2])
maps.plot(P[1], ax=ax, cmap='gray', cbar=cbar)
ax.set_axis_off()

ax = fig.add_subplot(g[0,3])
maps.plot(P, ax=ax, satnorm=True, mask_color='0.5', cbar=cbar)
ax.set_axis_off()

ax = fig.add_subplot(g[1,0])
maps.plot(radmap, ax=ax, cmap='CMRmap', mask_color='0.5', cbar=cbar)
ax.set_axis_off()

ax = fig.add_subplot(g[1,1])
maps.plot(adaptmap, ax=ax, cmap='binary', cmax=2.0, mask_color='c', cbar=cbar)
ax.set_axis_off()

plt.ion()
plt.draw()
