"""
Test the AxesReport class for data plots.
"""

import os

import numpy as np

from spc.tools import reports


testdir = os.path.splitext(__file__)[0]
if not os.path.isdir(testdir):
    os.makedirs(testdir)

report_fn = os.path.join(testdir, 'example-report.pdf')

XNORM = True
YNORM = True
ROWS = 5
COLS = 3
NPLOTS = int(1.5 * ROWS * COLS)

rpt = reports.AxesReport(report_fn, polar=False, naxes=NPLOTS, rows=ROWS, cols=COLS,
        xnorm=XNORM, ynorm=YNORM, numloc='bottom left')

rpt.set_label_fmt(weight='bold')
rpt.page.set_tight_layout(True)

for i in xrange(NPLOTS):
    ax = rpt.next_axes()

    mu = np.random.rand(2)
    sigma = np.random.rand(2)
    X = mu[0] + sigma[0] * np.random.randn(100)
    #X = 2 * np.pi * np.random.rand(100)  # for polar testing
    Y = mu[1] + sigma[1] * np.random.randn(100)
    ax.plot(X, Y, 'r.', ms=6, alpha=0.7)

    ax.tick_params(labelsize='x-small')

    if rpt.firstonpage:
        ax.set_ylabel('Y')
    else:
        ax.set_yticklabels([])
    if rpt.lastonpage:
        ax.set_xlabel('X')

    #if i % 5 == 0:
        #rpt.breakline()

rpt.close()
