"""
Test directioanl information implementation in tools.binned.
"""

import os
import matplotlib.pyplot as plt

from spc import store
from spc.lib import labels, cell, motion
from spc.tools import maps, binned, paths, arrays


outdir = os.path.splitext(__file__)[0]
if not os.path.isdir(outdir):
    os.makedirs(outdir)


c_id = 8
savefig = False

C = cell.record(c_id)
tag = labels.session_cell_id(c_id)
print 'Computing directional information for {}'.format(tag)

S = cell.session_for(c_id)

R, phi = S.dirmap(C, bins=36)
Rs = arrays.circblur(R, degrees=6.0)
I, p = S.directional_info(C, pvalue=True)

print 'I_spike = {:g}'.format(I)
print 'p < {:g}'.format(p)

fig = plt.figure(14, (9,7))
fig.clear()
ax = fig.add_subplot(111)
ax.plot(phi, R, 'r-x')
ax.plot(phi, Rs, 'b-', lw=2, alpha=0.6)
ax.set_xlim(*motion.MDIR_RANGE)
ax.set_ylim(bottom=0.0)
ax.set_title('{}\nI = {:.4f} bits/spk (p < {:g})'.format(tag, I, p))


if savefig:
    savefn = paths.uniquify(os.path.join(outdir,
        'dir-info-%04d' % c_id), ext='png', fmt='%s-%02d')
    plt.savefig(savefn)
    print 'Saved: {}'.format(savefn)

plt.draw()
plt.show()
