"""
Validating the pandas groupby expression in a summary statistic.
"""

import numpy as np
import pandas as pd

from pouty import ConsolePrinter

from spc import store
from spc.lib import data


# Set up the data
props = data.properties_dataframe()
props_by_rat = props.groupby('rat')
column = 'phase_coh'
ddof = 0

# Within-rat means
x_rat = props_by_rat[column].mean()

# Rat-based mean and standard deviation
mu = x_rat.mean()
sigma = x_rat.std(ddof=ddof)

# Manual groupby
rats = set(props['rat'])
x = []
for rat in rats:
    rat_values = props[column][props['rat'] == rat]
    x.append(rat_values.mean())
mu_manual = np.mean(x)
sigma_manual = np.std(x, ddof=ddof)

# Print
out = ConsolePrinter(prefix='GroupbyTest', prefix_color='purple')
out('Pandas: {} = {:.4f} +- {:.4f}', column, mu, sigma)
out('Numpy: {} = {:.4f} +- {:.4f}', column, mu_manual, sigma_manual)
