"""
Fix kernel width (and baseline) to match neighborhood radius.
"""

from __future__ import division

import numpy as np
import matplotlib.pyplot as plt


MINRAD = 5.0
MAXRAD = 50.0
N_CURVES = 10

HFRAC = 0.35


cmap = plt.get_cmap('rainbow')

plt.ioff()
fig = plt.figure(figsize=(18.5, 9.5))
ax = fig.add_subplot(111)

radius = np.linspace(MINRAD, MAXRAD, N_CURVES)
hwidths = HFRAC * radius

xmin, xmax = -2*MAXRAD, 2*MAXRAD
r = np.linspace(xmin, xmax, 512)
pkw = dict(lw=2, ls='-')


def Gk(maxr, r, h):
    G = lambda x: np.exp(-x**2 / (2 * h**2)) / (np.sqrt(2*np.pi) * h)
    return G(r) - G(maxr)


for i,(h,rad) in enumerate(zip(hwidths, radius)):
    col = cmap(i/(N_CURVES-1))
    ax.plot(r, Gk(rad, r, h), c=col, label='%.1f' % rad, **pkw)
    ax.axvline(-rad, 0, 1, c=col, lw=0.75, ls='--')
    ax.axvline(rad, 0, 1, c=col, lw=0.75, ls='--')

ax.axhline(0, 0, 1, c='k')

ymin, ymax = ax.axis()[2:]
ax.set_ylim(bottom=ymin-0.1*(ymax-ymin))
ax.set(xlabel='Radius (%)', ylabel=r'$G_k$', xlim=(xmin,xmax))
ax.legend(loc='upper right')

fig.suptitle('Kernels (%g): %g to %g%%' % (HFRAC,MINRAD,MAXRAD))

plt.ion()
plt.show()
