"""
Test using decorator.decorator on method functions.
"""

import inspect
from decorator import decorator


@decorator
def step(f, *args, **kwargs):
    self = args[0]
    self._step_enter(f, args, kwargs)
    res = f(*args, **kwargs)
    self._step_exit(f, args, kwargs)
    return res

def ppdict(d):
    for k, v in sorted(d.iteritems()):
        print ' *', k, '=', repr(v)


class Context(object):

    label = 'context'
    _steps = []

    def __init__(self, x):
        self.x = x

    def _step_enter(self, f, args, kwargs):
        print '_step_enter:', f.__name__
        spec = inspect.getargspec(f)
        info = {}
        info['classname'] = self.__class__.__name__
        info['methodname'] = f.__name__
        info['argnames'] = spec.args[1:]
        info['argvalues'] = args[1:]
        info['default'] = spec.defaults
        info['kwname'] = spec.keywords
        info['kwvalues'] = kwargs
        info['label'] = self.label
        ppdict(info)

        print '-----------'
        params = { k:v for k, v in zip(info['argnames'], info['argvalues']) }
        ppdict(params)

    def _step_exit(self, f, args, kwargs):
        print '_step_exit:', f.__name__


class Run(Context):

    label = 'data run'

    @step
    def addor(self, a, subtract=False, alpha=0.5, beta=1.0, gamma=1.5):
        """This is the method docstring."""
        if subtract:
            return a - self.x
        return a + self.x

    @step
    def modulo(self, x, mod=360.0):
        """Return the phase angle in degrees."""
        return x % mod


test = Run(20)
print test.addor(7, alpha=0.7, beta=0.2)
print test.modulo(710)
