#!/usr/bin/env python

"""
Search for recorded clusters that are missing spike train data.
"""

import os

import numpy as np
import matplotlib.pyplot as plt

from spc import store
from spc.output import log
from spc.lib import parsers, session
from spc.lib.data import Arenas


# Generate list of random recording samples
df = store.get(readonly=True)
recs = df.root.recordings
stable = df.root.sessions

# Get random sample from cell recordings from the cylinder arena
log('Building list of valid clusters to check...')
sample_cells = []
for s in stable.where('arena==%d' % Arenas.circle):
    for r in recs.where('session_id==%d' % s['id']):
        sample_cells.append(int(r['id']))

log('Sampling {} cells from the cylinder', len(sample_cells))


for i in sample_cells:
    cell = recs[i]
    ttc = parsers.parse_ttc(cell)
    S = session.get(cell['session_id'])
    label = 'Rat {}, Day {}, Cell {}'.format(S.rat, S.day, cell['ttc'])
    if ttc not in S.clusters:
        log("Missing: spike train {}", ttc, label, error=True)


store.close()
