"""
Fix the phase interpolation issue and weirdness with improper unwrapping.
"""

import numpy as np
from scipy.interpolate import interp1d
import matplotlib.pyplot as plt

from spc import store
from spc.lib.time import select_from
from spc.lib.lfp import ContinuousData
from spc.lib.cluster import ClusterData


S_ID = 27
TTC = (7,1)
START = 2000.0
DUR = 1000.0

df = store.get(True)
spath = df.root.sessions[S_ID]['group']

plt.ioff()

plt.close(101)
fig = plt.figure(figsize=(16, 7), num=101)
axtl = fig.add_subplot(231)
axtc = fig.add_subplot(232)
ax = fig.add_subplot(212)

cdata = ClusterData(spath, TTC)
spikes = cdata.spikes

lfp = ContinuousData(spath)
t, phase = lfp.t, lfp.phase

tlim = START, START + DUR
six = select_from(spikes, [tlim])
spikes = spikes[six]
sphase = lfp.F('phase', spikes)

pix = select_from(t, [tlim])
t, phase = t[pix], phase[pix]

uphase = np.unwrap(phase)
Fu = interp1d(t, uphase)
sphase_fixed = Fu(spikes) % (2*np.pi)
sphase_fixed[sphase_fixed > np.pi] -= 2 * np.pi


axtl.hist(cdata.spikes, bins=64, histtype='stepfilled', zorder=-1, alpha=0.3)
axtl.hist(cdata.spikes, bins=64, linewidth=1, color='k', histtype='step')

axtc.hist(sphase, bins=np.linspace(-np.pi, np.pi, 64), histtype='stepfilled', zorder=-1, alpha=0.3)
axtc.hist(sphase, bins=np.linspace(-np.pi, np.pi, 64), linewidth=1, color='k', histtype='step')

axtc.hist(sphase_fixed, bins=np.linspace(-np.pi, np.pi, 64), facecolor='r', histtype='stepfilled', zorder=-1, alpha=0.3)
axtc.hist(sphase_fixed, bins=np.linspace(-np.pi, np.pi, 64), linewidth=1, color='k', histtype='step')

ax.plot(t, phase, 'k-', lw=0.75, zorder=-2)
ax.scatter(spikes, sphase, s=30, c='r', linewidths=0, alpha=0.6)
ax.scatter(spikes, sphase_fixed, s=30, facecolor='none', edgecolor='g', linewidths=1.5, alpha=0.6)

ax.set(xlim=(START, START+10), ylim=(-1.5*np.pi, 1.5*np.pi), xlabel='Time (s)',
        ylabel='Theta Phase')



store.close()

plt.ion()
plt.draw()
plt.show()
