"""
Test Kempter phase regression on spiking data.
"""

import os
import numpy as np
import matplotlib as mpl
import matplotlib.pyplot as plt
import scipy.optimize as opt

from spc.ana.characterize import CellProperties
from spc.lib import theta, labels
from spc.tools import plots, radians


outdir = os.path.splitext(__file__)[0]
if not os.path.isdir(outdir):
    os.makedirs(outdir)


c_id = 1
savefig = False

tag = labels.session_cell_id(c_id)
print 'Getting data for {}'.format(tag)

rundir = '/Users/joe/projects/spc/analysis/cell-properties/alpha/01'
props = CellProperties(rundir)
df = props.get_datafile()

rate = props.read_array('pixels/rate/id%04d' % c_id)
phase = props.read_array('pixels/phase/id%04d' % c_id)
#rate = props.read_array('rate_estimates/id%04d' % c_id)
#phase = props.read_array('spike_phase/id%04d' % c_id)

Reg = theta.KempterPhaseCorrelation(rate, phase)
Reg.maximize_residuals()
Reg.estimate_intercept()
Reg.correlation_and_pvalue()

slope, phi0, rho, pval = 2 * np.pi * Reg.a_hat, Reg.phi0, Reg.rho_hat, Reg.p_value

print 'Slope = {:g} (a_hat = {:g})'.format(slope, Reg.a_hat)
print 'Phi = {:g}'.format(phi0)
print 'R-value = {:g}'.format(rho)
print 'P-value = {:g}'.format(pval)

radfmt = radians.RadianFormatter(inline=False)
mpl.rc('xtick', direction='out')
mpl.rc('ytick', direction='out')

def _plot_phasereg(m, x, sl, phi):
    plt.plot(x, m*2*np.pi + phi + sl*x, 'r-', lw=2, alpha=0.6)

fig = plt.figure(12, (9,7))
fig.clear()
ax = fig.add_subplot(111)

rlim = np.array([rate.min(), rate.max()])
rate = np.tile(rate, 2)
phase = np.r_[phase, phase + 2*np.pi]
plots.heatmap(rate, phase, ax=ax, cmap='gray_r')

for cycle in xrange(-5, 5):
    _plot_phasereg(cycle, rlim, slope, phi0)

plots.despine(ax)
ax.set_yticks([0, np.pi, 2*np.pi])
ax.set_ylim(-np.pi, 3*np.pi)
ax.yaxis.set_major_formatter(radfmt)
ax.set_title('{}: r = {:.3f}, p < {:g}'.format(tag, rho, pval))

if savefig:
    savefn = paths.uniquify(os.path.join(outdir,
        'phase-regress-%04d' % c_id), ext='png', fmt='%s-%02d')
    plt.savefig(savefn)
    print 'Saved: {}'.format(savefn)

plt.draw()
plt.show()
mpl.rc_file_defaults()
