"""
Test for developing improving p-value shuffling procedure.
"""

from __future__ import division

import os
import time as stdtime
import numpy as np
from scipy.interpolate import interp1d

from spc import store
from spc.lib import labels, cell, motion, time, session
from spc.tools import binned, paths


c_id = 4
savefig = False
min_offset = 20.0
speed = 'fast'
tlim = None
bursts = False
samples = session.INFO_PVAL_SAMPLES

tag = labels.session_cell_id(c_id)
C = cell.record(c_id)
S = cell.session_for(c_id)
print 'Testing pvalue for {}'.format(tag)

I = S.directional_info(C)
print 'Directional I_spike = {:.4f} bits/spike'.format(I)

(ts, ds), (_, dp) = S._dirdata(C, speed, tlim, bursts)

# Old method
np.random.seed(11235)
t0 = stdtime.time()
offsets = S.duration * np.random.rand(samples)
I_shuffled = np.empty_like(offsets)
for i, offset in enumerate(offsets):
    _, ds = S._spkdirdata(C, speed, tlim, bursts, offset)
    I_shuffled[i] = binned.dirinfo(ds, dp)
pval = ((I_shuffled >= I).sum() + 1) / I_shuffled.size
pval = min(pval, 1.0)  # avoid 1.001
print 'Old method P < {:g}'.format(pval)
print 'Elapsed time = {:.3f} seconds'.format(stdtime.time() - t0)

# New library method
print 'Computing compact shuffling...'
np.random.seed(11235)
t0 = stdtime.time()

Inew, pvalnew = S.directional_info(C, pvalue=True)

print 'New method P < {:g}'.format(pvalnew)
print 'Elapsed time = {:.3f} seconds'.format(stdtime.time() - t0)
