"""
Test refactoring binned ratemap using spikemap and occmap.
"""

import os
import numpy as np
import matplotlib.pyplot as plt

from spc import store
from spc.lib import labels, cell
from spc.tools import maps, binned, paths


outdir = os.path.splitext(__file__)[0]
if not os.path.isdir(outdir):
    os.makedirs(outdir)


c_id = 8
savefig = True

tag = labels.session_cell_id(c_id)
print 'Computing ratemaps for {}'.format(tag)

C = cell.record(c_id)
S = cell.session_for(c_id)
ratemap = S.ratemap(C, adaptive=False, min_occ=0.5)

(ts, xs, ys), (tp, xp, yp) = S._posdata(C, 'fast', None, False)
smap = binned.spikemap(xs, ys)
omap = binned.occmap(xp, yp, min_occ=0.5, freq=S.motion.Fs)
valid = np.logical_not(np.isnan(omap))

H = np.zeros_like(omap) + np.nan
H[valid] = smap[valid] / omap[valid]
ratemap2 = H

if np.all(ratemap[valid] == ratemap2[valid]):
    print 'All pixels are identical!'
else:
    print 'Max. pixel difference = {}'.format(
            np.max(np.abs(ratemap[valid] - ratemap2[valid])))

# --- plotting ---

fig = plt.figure(30, (12, 6))
fig.clear()
ax = fig.add_subplot(121)
maps.plot(ratemap, ax=ax, cmin=0.0, cbar=True, mask_color='0.8')
ax.set_axis_off()
ax.set_title(tag)

ax = fig.add_subplot(122)
maps.plot(ratemap2, ax=ax, cmin=0.0, cbar=True, mask_color='0.8')
ax.set_axis_off()
ax.set_title('Refactored map')

if savefig:
    savefn = paths.uniquify(os.path.join(outdir,
        'rmaps-%04d' % c_id), ext='png', fmt='%s-%02d')
    plt.savefig(savefn)
    print 'Saved: {}'.format(savefn)

plt.draw()
plt.show()
