"""
Test Skaggs information implementation in tools.binned.
"""

import os
import matplotlib.pyplot as plt

from spc import store
from spc.lib import labels, cell
from spc.tools import maps, binned, paths


outdir = os.path.splitext(__file__)[0]
if not os.path.isdir(outdir):
    os.makedirs(outdir)


c_id = 201
savefig = False

rec = cell.record(c_id)
tag = labels.session_cell_id(c_id)
print 'Computing information for {}'.format(tag)

#df = store.get()
#ratemap = df.get_node('/ratemaps/id%04d' % c_id)
S = cell.session_for(c_id)

I, p = S.spatial_info(rec, pvalue=True, use_gen=True)
binmap = S.ratemap(rec, adaptive=False, min_occ=binned.INFO_MIN_OCC)

print 'I_spike = {:g}'.format(I)
print 'p < {:g}'.format(p)

fig = plt.figure(13, (15.275, 5.4125))
fig.clear()
ax = fig.add_subplot(121)
ax.hist(
#maps.plot(ratemap, ax=ax, cmin=0.0, cbar=True, mask_color='0.8')
ax.set_axis_off()
ax.set_title(tag)

ax = fig.add_subplot(122)
maps.plot(binmap, ax=ax, cmin=0.0, cbar=True, mask_color='0.8')
ax.set_axis_off()
ax.set_title('I = {:.4f} bits/spk (p < {:g})'.format(I, p))

if savefig:
    savefn = paths.uniquify(os.path.join(outdir,
        'spatial-info-%04d' % c_id), ext='png', fmt='%s-%02d')
    plt.savefig(savefn)
    print 'Saved: {}'.format(savefn)

plt.draw()
plt.show()
