"""
Test spike speed distributions for speed filtering problems.
"""

import os
import numpy as np
import matplotlib.pyplot as plt

from spc import store
from spc.output import log
from spc.lib import labels, cell, motion, time
from spc.tools import maps, binned, paths, arrays


outdir = os.path.splitext(__file__)[0]
if not os.path.isdir(outdir):
    os.makedirs(outdir)

c_id = 102
min_map = 10.0
min_fast = 5.0
min_slow = 2.5
smax = 40.0
savefig = True

C = cell.record(c_id)
S = cell.session_for(c_id)
cdata = S.get_cluster(C)
mdata = S.motion
tag = labels.session_cell_id(c_id)
log('Loading data for {}', tag)

# Spike figure
plt.ioff()
fig, ax = plt.subplots(2, 4, sharex=True, sharey=False, figsize=(23.95, 7.5))
fig.suptitle('Spike Speed Distros\n{}'.format(tag))

#still = cdata.still_spikes
#slow = cdata.slow_spikes
#fast = cdata.fast_spikes
spikes = cdata.spikes
#spkspeed = mdata.F('speed_orig', spikes) / 0.1625

def _hist(ax, data, title=None):
    ax.hist(data, bins=2*int(smax), range=(0, smax))
    ax.axvline(min_slow, c='k')
    ax.axvline(min_fast, c='r')
    ax.axvline(min_map, c='m')
    ax.set_xlim(0, smax)
    if title:
        ax.set_title(title)

#_hist(ax[0][0], mdata.F('speed_orig', still) / 0.1625, 'Spike Still')
#_hist(ax[0][1], mdata.F('speed_orig', slow) / 0.1625, 'Spike Slow')
#_hist(ax[0][2], mdata.F('speed_orig', fast) / 0.1625, 'Spike Fast')
#_hist(ax[0][3], mdata.F('speed_orig', spikes) / 0.1625, 'All Spikes')

#_hist(ax[1][0], spkspeed[time.select_from(spikes, mdata.still_intervals)], 'Spike Stillint')
#_hist(ax[1][1], spkspeed[time.select_from(spikes, mdata.slow_intervals)], 'Spike Slowint')
#_hist(ax[1][2], spkspeed[time.select_from(spikes, mdata.fast_intervals)], 'Spike Fastint')

#_hist(ax[2][0], spkspeed[spkspeed<min_slow], 'Spike Still Itrp/Thr')
#_hist(ax[2][1], spkspeed[(spkspeed>=min_slow) * (spkspeed<min_fast)], 'Spike Slow Itrp/Thr')
#_hist(ax[2][2], spkspeed[spkspeed>=min_fast], 'Spike Fast Itrp/Thr')

spkfixed = mdata.F('speed_cm', spikes)

_hist(ax[0][0], spkfixed[mdata.speed_filter(spikes, 'still')], 'Rawspikes Filter Still')
_hist(ax[0][1], spkfixed[mdata.speed_filter(spikes, 'slow')], 'Rawspikes Filter Slow')
_hist(ax[0][2], spkfixed[mdata.speed_filter(spikes, 'fast')], 'Rawspikes Filter Fast')
_hist(ax[0][3], spkfixed, 'All Rawspikes')

_hist(ax[1][0], mdata.speed_cm[mdata.still_index], 'Motion Still')
_hist(ax[1][1], mdata.speed_cm[mdata.slow_index], 'Motion Slow')
_hist(ax[1][2], mdata.speed_cm[mdata.fast_index], 'Motion Fast')
_hist(ax[1][3], mdata.speed_cm, 'All Motion')

#ax[2][0].hist(mdata.speed_orig[mdata.still_index] / mdata.speed_cm[mdata.still_index],
        #bins=200, range=(0,0.5))
#ax[2][1].hist(mdata.speed_orig[mdata.slow_index] / mdata.speed_cm[mdata.slow_index],
        #bins=200, range=(0,0.5))
#ax[2][2].hist(mdata.speed_orig[mdata.fast_index] / mdata.speed_cm[mdata.fast_index],
        #bins=200, range=(0,0.5))
#ax[2][3].hist(mdata.speed_orig / mdata.speed_cm, bins=200, range=(0,0.5))

# Combined figure
#fig, ax = plt.subplots(2, 4, sharex=True, sharey=True, figsize=(12, 7))
#fig.suptitle('Spike and Motion Speed Distros\n{}'.format(tag))

#_hist(ax[0][0], mdata.F('speed_cm', still), 'Spike Still')
#_hist(ax[0][1], mdata.F('speed_cm', slow), 'Spike Slow')
#_hist(ax[0][2], mdata.F('speed_cm', fast), 'Spike Fast')
#_hist(ax[0][3], mdata.F('speed_cm', spikes), 'All Spikes')

#_hist(ax[1][0], mdata.speed[mdata.still_index], 'Motion Still')
#_hist(ax[1][1], mdata.speed[mdata.slow_index], 'Motion Slow')
#_hist(ax[1][2], mdata.speed[mdata.fast_index], 'Motion Fast')
#_hist(ax[1][3], mdata.speed, 'All Motion')


if savefig:
    savefn = paths.uniquify(os.path.join(outdir,
        'speed-test-%04d' % c_id), ext='png', fmt='%s-%02d')
    plt.savefig(savefn)
    print 'Saved: {}'.format(savefn)

plt.ion()
plt.show()
plt.draw()
