"""
Test speed information implementation in tools.binned.
"""

import os
import matplotlib.pyplot as plt

from spc import store
from spc.lib import labels, cell, motion
from spc.tools import maps, binned, paths, arrays


outdir = os.path.splitext(__file__)[0]
if not os.path.isdir(outdir):
    os.makedirs(outdir)


c_id = 223
savefig = False

C = cell.record(c_id)
tag = labels.session_cell_id(c_id)
print 'Computing speed information for {}'.format(tag)

S = cell.session_for(c_id)

R, speeds = S.speedmap(C)
I, p = S.speed_info(C, pvalue=True)

print 'I_speed = {:g} bits/spk'.format(I)
print 'p < {:g}'.format(p)

fig = plt.figure(14, (9,7))
fig.clear()
ax = fig.add_subplot(111)
ax.plot(speeds, R, 'k-o')
ax.set_xlim(binned.DEFAULT_SPEED_MIN, binned.DEFAULT_SPEED_MAX)
ax.set_ylim(bottom=0.0)
ax.set_title('{}\nI_speed = {:.4f} bits/spk (p < {:g})'.format(tag, I, p))


if savefig:
    savefn = paths.uniquify(os.path.join(outdir,
        'speed-info-%04d' % c_id), ext='png', fmt='%s-%02d')
    plt.savefig(savefn)
    print 'Saved: {}'.format(savefn)

plt.draw()
plt.show()

