"""
Test rewrite of intervals and selection in time module.
"""

import numpy as np
import matplotlib.pyplot as plt

from spc.lib import session
from spc.lib.time import select_from, intervals_where


s_id = 11
min_dur = 0.25
gap_tol = None #0.1

S = session.get(s_id)
mdata = S.motion
t, speed, md = mdata.t, mdata.speed, mdata.md
Fs = mdata.Fs

def printvar(name, data):
    print '%s.shape =' % name, data.shape, ': range = (%g, %g)' % (
            data.min(), data.max())
printvar('t', t)
printvar('speed', speed)
printvar('md', md)
print 'Total dur =', t.ptp(), ': Fs =', Fs

fastints = intervals_where(t, [speed>10], min_dur=min_dur, freq=Fs,
        gap_tol=gap_tol)
print '---\nfast intervals:', len(fastints)
fastdurs = np.diff(fastints, axis=1)
print 'Average duration:', fastdurs.mean()
print 'Total duration:', fastdurs.sum()
print 'Range of durations: (%g, %g)' % (fastdurs.min(), fastdurs.max())
fastspeeds = speed[select_from(t, fastints)]
print 'Average speed:', fastspeeds.mean()
print 'Range of speeds: (%g, %g)' % (fastspeeds.min(), fastspeeds.max())

mdints = intervals_where(t, [md>=0, md<np.pi/4], min_dur=min_dur, freq=Fs,
        gap_tol=gap_tol)
print '---\nmd intervals:', len(mdints)
mddurs = np.diff(mdints, axis=1)
print 'Average duration:', mddurs.mean()
print 'Total duration:', mddurs.sum()
print 'Range of durations: (%g, %g)' % (mddurs.min(), mddurs.max())
mddirs = md[select_from(t, mdints)]
print 'Average direction:', mddirs.mean()
print 'Range of directions: (%g, %g)' % (mddirs.min(), mddirs.max())

fastmdints = intervals_where(t, [speed>10, md>=0, md<np.pi/4], min_dur=min_dur,
        freq=Fs, gap_tol=gap_tol)
print '---\nfastmd intervals:', len(fastmdints)
fastmddurs = np.diff(fastmdints, axis=1)
print 'Average duration:', fastmddurs.mean()
print 'Total duration:', fastmddurs.sum()
print 'Range of durations: (%g, %g)' % (fastmddurs.min(), fastmddurs.max())
fastmddirs = md[select_from(t, fastmdints)]
fastmdspeeds = speed[select_from(t, fastmdints)]
print 'Average direction:', fastmddirs.mean()
print 'Range of directions: (%g, %g)' % (fastmddirs.min(), fastmddirs.max())
print 'Average speed:', fastmdspeeds.mean()
print 'Range of speeds: (%g, %g)' % (fastmdspeeds.min(), fastmdspeeds.max())


wasint = plt.isinteractive()
plt.ioff()
fig = plt.figure(1)
fig.clear()

ax = plt.subplot(311)
ax.hist(fastdurs, 128)
ax.set_ylabel('interval durations')

ax = plt.subplot(312)
ax.hist(fastspeeds, 128)
ax.set_ylabel('fastint speeds')

ax = plt.subplot(313)
ax.hist(mddirs, 128)
ax.set_ylabel('directions')

plt.show()
if wasint:
    plt.ion()
plt.draw()
