#!/usr/bin/env python

"""
Test trajectory movie generation with FigureMovie and TimeTracePlot
"""

import os

import matplotlib.pyplot as plt

from spc import store
from spc.lib.motion import MotionData
from spc.tools.movies import FigureMovie
from spc.tools.plots import TimeTracePlot


testdir, _ = os.path.split(__file__)
moviepath = os.path.join(testdir, 'traj-movie-test.mp4')

df = store.get(True)
spath = df.root.sessions[0]['group']

movie = FigureMovie(moviepath, fps=30.0, duration=20.0,
            aa=2.0, figsize=(6,6))
fig = movie.get_frame()

ax = plt.axes([0,0,1,1])  # full-figure axes
ax.axis('equal')
ax.set(xticks=[], yticks=[])
for spine in ax.spines.itervalues():
    spine.set_visible(False)

mdata = MotionData(spath)
t0 = mdata.t[0]
speedup = 2.0

ax.plot(mdata.x, mdata.y, 'k-', lw=0.5, alpha=0.5, zorder=-1)
trace = TimeTracePlot(mdata.t, mdata.x, mdata.y,
            dt=15.0, tau=5.0, cmap='CMRmap_r', lw=3.5)
h = ax.plot([0], [0], 'wo', mew=1.5, mfc='w', mec='k', ms=9, zorder=5)
head = h[0]

def update(t):
    t1 = speedup * t + t0
    trace.plot(t1, ax=ax)
    head.set_xdata([mdata.F('x', t1)])
    head.set_ydata([mdata.F('y', t1)])

def label(t):
    t1 = speedup * t + t0
    return 't = %.2fs' % t1

movie.set_update_function(update)
movie.set_label_function(label)
movie.set_label_fmt(size='large')

#movie.snapshot([0,10,20])
movie.render()
movie.view()
store.close()
